@@ -1,4 +1,4 @@
 from response_functions.common import *
-from response_functions.massless_dirac_fermions import Massless_Dirac_Fermions
+from response_functions.massless_dirac_fermions import Massless_Dirac_Fermions, Massless_Dirac_Fermions_B
 from response_functions.parabolic_bands import Electron_Liquid
 from response_functions.hexagonal_boron_nitride import * 
\ No newline at end of file
